@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# Application Name - Health Check V0.5.0-9
+# Application Name - Health Check V0.5.1-1
 # Date 17 February 2010
 # Author - Greg Roberts (Noobmonkey @ Maemo Talk)
 # Contact - Me@Greg-roberts.com
@@ -39,6 +39,13 @@ import gobject
 # can be found here - http://repository.maemo.org/extras-devel/pool/fremantle/free/source/n/netmon/
 import gn_cellinfo
 import gtk
+import hildon
+
+#for phone orientation call
+import dbus.glib
+
+#For bluetooth - apt-get install python-bluetooth
+import bluetooth
 
 # osso_c = osso.Context("healthcheck", "666", True)
 
@@ -47,6 +54,10 @@ from threading import Thread
 import time
 gtk.gdk.threads_init()
 
+import pygtk
+
+
+
 
 
 # Set a global variable - used to send the GPS info from a function back onto its label in the GUI. I'm sure there is a much better way returning
@@ -150,7 +161,13 @@ class Ui_MainWindow(object):
         self.lbl_SysLocale.setObjectName("lbl_SysLocale")
         self.lbl_SysLocale.setText("System Locale")
 
-       
+        
+        
+
+
+
+        #self.lst_Listwidget1.setGeometry(QtCore.QRect(10, 210, 171, 200))
+        
         
         
 
@@ -171,7 +188,7 @@ class Ui_MainWindow(object):
         font.setPointSize(18)
         #Accelorator information
         self.lbl_Accel_Info = QtGui.QLabel(self.tab)
-        self.lbl_Accel_Info.setGeometry(QtCore.QRect(200, 30, 400, 21))
+        self.lbl_Accel_Info.setGeometry(QtCore.QRect(200, 30, 590, 21))
         self.lbl_Accel_Info.setFont(font)
         self.lbl_Accel_Info.setObjectName("lbl_Accel_Info")
 
@@ -214,6 +231,20 @@ class Ui_MainWindow(object):
         self.lbl_SysLocaleInfo.setObjectName("lbl_SysLocaleInfo")
         self.lbl_SysLocaleInfo.setText("Sys Locale Info")
 
+                
+       
+
+        #self.listWidget = QtGui.QListWidget(self.tab)
+        #self.listWidget.setGeometry(QtCore.QRect(10, 210, 600, 200))
+        #for i in range(10):
+            #item = QtGui.QListWidgetItem("Item %i" % i)
+            #self.listWidget.addItem(item)
+        #self.listWidget.setObjectName("lbl_listWidget")
+        #self.listWidget.setFont(font)
+        #self.listWidget.setAlternatingRowColors(True)
+        #self.listWidget.setResizeMode(QtGui.QListView.Adjust)
+        #self.listWidget.addItem("Testing listbox")
+        #self.listWidget.show()
         
         
         # Setup and draw the button
@@ -234,82 +265,71 @@ class Ui_MainWindow(object):
 
         # Set up the GPS Info label
         self.lbl_GpsPos = QtGui.QLabel(self.tab_2)
-        self.lbl_GpsPos.setGeometry(QtCore.QRect(10, 60, 190, 21))
+        self.lbl_GpsPos.setGeometry(QtCore.QRect(10, 0, 190, 21))
         self.lbl_GpsPos.setFont(font)
         self.lbl_GpsPos.setObjectName("lbl_GpsPos")
         self.lbl_GpsPos.setText("GPS Position")
         
-        # Set up the GPS Info label
-        #self.lbl_alt = QtGui.QLabel(self.tab_2)
-        #self.lbl_alt.setGeometry(QtCore.QRect(10, 90, 190, 21))
-        #self.lbl_alt.setFont(font)
-        #self.lbl_alt.setObjectName("lbl_alt")
-        #self.lbl_alt.setText("GPS Altitude")
         
         # GPS Info Field
         self.lbl_Gps_Info = QtGui.QLabel(self.tab_2)
-        self.lbl_Gps_Info.setGeometry(QtCore.QRect(220, 60, 420, 21))
+        self.lbl_Gps_Info.setGeometry(QtCore.QRect(220, 0, 420, 21))
         self.lbl_Gps_Info.setObjectName("lbl_Gps_Info")
         self.lbl_Gps_Info.setFont(font)
 
-        # GPS Info Field
-        #self.lbl_Alt_Info = QtGui.QLabel(self.tab_2)
-        #self.lbl_Alt_Info.setGeometry(QtCore.QRect(220, 90, 420, 21))
-        #self.lbl_Alt_Info.setObjectName("lbl_Alt_Info")
-        #self.lbl_Alt_Info.setFont(font)
 
         # This label is for the phone signal (Label only)
         self.lbl_Psignal = QtGui.QLabel(self.tab_2)
-        self.lbl_Psignal.setGeometry(QtCore.QRect(10, 240, 190, 21))
+        self.lbl_Psignal.setGeometry(QtCore.QRect(10, 60, 190, 21))
         self.lbl_Psignal.setFont(font)
         self.lbl_Psignal.setObjectName("lbl_Psignal")
         self.lbl_Psignal.setText("Phone Signal")
 
         # This label is for the phone RNC (Label only)
         self.lbl_PRNC = QtGui.QLabel(self.tab_2)
-        self.lbl_PRNC.setGeometry(QtCore.QRect(10, 270, 190, 21))
+        self.lbl_PRNC.setGeometry(QtCore.QRect(10, 90, 190, 21))
         self.lbl_PRNC.setFont(font)
         self.lbl_PRNC.setObjectName("lbl_PRNC")
         self.lbl_PRNC.setText("Network Status")
         
         # This label is for the Phone Services (Label only)
         self.lbl_PhoneServices = QtGui.QLabel(self.tab_2)
-        self.lbl_PhoneServices.setGeometry(QtCore.QRect(10, 300, 190, 21))
+        self.lbl_PhoneServices.setGeometry(QtCore.QRect(10, 120, 190, 21))
         self.lbl_PhoneServices.setFont(font)
         self.lbl_PhoneServices.setObjectName("lbl_PhoneServices")
         self.lbl_PhoneServices.setText("Phone Services")
 
         # This label is for the Cell ID(Label only)
         self.lbl_Cell_ID = QtGui.QLabel(self.tab_2)
-        self.lbl_Cell_ID.setGeometry(QtCore.QRect(10, 330, 190, 21))
+        self.lbl_Cell_ID.setGeometry(QtCore.QRect(10, 150, 190, 21))
         self.lbl_Cell_ID.setFont(font)
         self.lbl_Cell_ID.setObjectName("lbl_Cell_ID")
         self.lbl_Cell_ID.setText("Phone Cell_ID")
         
         # This label is for the Phone Signal info (Label only)
         self.lbl_pSignal_Info = QtGui.QLabel(self.tab_2)
-        self.lbl_pSignal_Info.setGeometry(QtCore.QRect(220, 240, 331, 21))
+        self.lbl_pSignal_Info.setGeometry(QtCore.QRect(220, 60, 331, 21))
         self.lbl_pSignal_Info.setFont(font)
         self.lbl_pSignal_Info.setObjectName("lbl_pSignal_Info")
         #self.lbl_pSignal_Info.setText("Phone Signal")
 
         # This label was Phone RNC info now net status (Label only)
         self.lbl_pRNC_Info = QtGui.QLabel(self.tab_2)
-        self.lbl_pRNC_Info.setGeometry(QtCore.QRect(220, 270, 331, 21))
+        self.lbl_pRNC_Info.setGeometry(QtCore.QRect(220, 90, 331, 21))
         self.lbl_pRNC_Info.setFont(font)
         self.lbl_pRNC_Info.setObjectName("lbl_pRNC_Info")
         #self.lbl_pRNC_Info.setText("Network Status")
 
         # This label is for the Phone services info (Label only)
         self.lbl_pServices_Info = QtGui.QLabel(self.tab_2)
-        self.lbl_pServices_Info.setGeometry(QtCore.QRect(220, 300, 331, 21))
+        self.lbl_pServices_Info.setGeometry(QtCore.QRect(220, 120, 331, 21))
         self.lbl_pServices_Info.setFont(font)
         self.lbl_pServices_Info.setObjectName("lbl_pServices_Info")
         #self.lbl_pServices_Info.setText("Phone Services")
 
         # This label is for the Cell ID info (Label only)
         self.lbl_CellID_Info = QtGui.QLabel(self.tab_2)
-        self.lbl_CellID_Info.setGeometry(QtCore.QRect(220, 330, 331, 21))
+        self.lbl_CellID_Info.setGeometry(QtCore.QRect(220, 150, 331, 21))
         self.lbl_CellID_Info.setFont(font)
         self.lbl_CellID_Info.setObjectName("lbl_CellID_Info")
         #self.lbl_CellID_Info.setText("Cell ID")
@@ -332,15 +352,15 @@ class Ui_MainWindow(object):
         font = QtGui.QFont()
         font.setPointSize(12)
         # Set up the Front Camera label
-        self.lbl_FrontCam = QtGui.QLabel(self.tab_3)
-        self.lbl_FrontCam.setGeometry(QtCore.QRect(10, 130, 131, 21))
-        self.lbl_FrontCam.setFont(font)
-        self.lbl_FrontCam.setObjectName("lbl_FrontCam")
-        self.lbl_FrontCam.setText("Front Camera")
+        #self.lbl_FrontCam = QtGui.QLabel(self.tab_3)
+        #self.lbl_FrontCam.setGeometry(QtCore.QRect(10, 130, 131, 21))
+        #self.lbl_FrontCam.setFont(font)
+        #self.lbl_FrontCam.setObjectName("lbl_FrontCam")
+        #self.lbl_FrontCam.setText("Camera Image")
 
         # This label is used to show the Front Camera widget
         self.lbl_CameraShow = QtGui.QLabel(self.tab_3)
-        self.lbl_CameraShow.setGeometry(QtCore.QRect(150, 10, 455, 341))
+        self.lbl_CameraShow.setGeometry(QtCore.QRect(0, 10, 455, 341))
         self.lbl_CameraShow.setFrameShape(QtGui.QFrame.Panel)
         self.lbl_CameraShow.setFrameShadow(QtGui.QFrame.Raised)
         self.lbl_CameraShow.setLineWidth(2)
@@ -350,12 +370,20 @@ class Ui_MainWindow(object):
         
         # Setup and draw the button
         self.pushButton_cam = QtGui.QPushButton(self.tab_3)
-        self.pushButton_cam.setGeometry(QtCore.QRect(0, 300, 151, 51))
+        self.pushButton_cam.setGeometry(QtCore.QRect(450, 250, 340, 51))
         self.pushButton_cam.setObjectName("pushButton_cam")
-        self.pushButton_cam.setText("Update")
+        self.pushButton_cam.setText("Front Camera")
         # Tell the button what to do when it is clicked. In this case i want it to run the updateTab1 function below
         QtCore.QObject.connect(self.pushButton_cam, QtCore.SIGNAL('clicked()'), self.updateTab3)
 
+        # Setup and draw the button
+        self.pushButton_cam2 = QtGui.QPushButton(self.tab_3)
+        self.pushButton_cam2.setGeometry(QtCore.QRect(450, 310, 340, 51))
+        self.pushButton_cam2.setObjectName("pushButton_cam2")
+        self.pushButton_cam2.setText("Back camera")
+        # Tell the button what to do when it is clicked. In this case i want it to run the updateTab1 function below
+        QtCore.QObject.connect(self.pushButton_cam2, QtCore.SIGNAL('clicked()'), self.updateTab3a)
+
         # Show the tab and draw contents
         self.tabWidget.addTab(self.tab_3, "")
 
@@ -365,7 +393,7 @@ class Ui_MainWindow(object):
 
         # Setup and draw the button
         self.pushButton_reboot = QtGui.QPushButton(self.tab_4)
-        self.pushButton_reboot.setGeometry(QtCore.QRect(10, 10, 371, 51))
+        self.pushButton_reboot.setGeometry(QtCore.QRect(10, 312, 391, 41))
         self.pushButton_reboot.setObjectName("pushButton_reboot")
         self.pushButton_reboot.setText("System Reboot")
         # Tell the button what to do when it is clicked. In this case i want it to run the updateTab1 function below
@@ -383,7 +411,7 @@ class Ui_MainWindow(object):
         # box of some sort
         self.textBrowser = QtGui.QTextBrowser(self.tab_5)
         self.textBrowser.setGeometry(QtCore.QRect(0, 10, 781, 301))
-        self.textBrowser.setText (" Health Check V 0.5.0-9 \n Greg Roberts (Maemo.org - Noobmonkey) \n me@greg-roberts.com \n \n For Bugs and Feature requests: \n http://talk.maemo.org/showthread.php?p=541457")
+        self.textBrowser.setText (" Health Check V 0.5.1-1 \n Greg Roberts (Maemo.org - Noobmonkey) \n me@greg-roberts.com \n \n For Bugs and Feature requests: \n http://talk.maemo.org/showthread.php?p=541457")
         # Make the font small!!!
         font = QtGui.QFont()
         font.setPointSize(20)
@@ -410,6 +438,9 @@ class Ui_MainWindow(object):
         QtCore.QMetaObject.connectSlotsByName(MainWindow)
         Thread(target=self.updateTab1()).start()
         
+
+    
+        
 # Funtion - update GPS - Using lib-location
     def updateGPS(self):
         global var_g_GPS
@@ -433,11 +464,12 @@ class Ui_MainWindow(object):
         gobject.idle_add(start_location, control)
 
         loop.run()
-        
-        # Set the GPS tabel text       
+
+    
+         # Set the GPS tabel text       
         self.lbl_Gps_Info.setText(var_g_GPS)
         #self.lbl_Alt_Info.setText(var_g_ALT)
-
+        
 
     def reboot_sys(self):
        
@@ -461,6 +493,20 @@ class Ui_MainWindow(object):
         image = QtGui.QPixmap(image_file)
         # Declare image, and tell it, that it is a pixmap, and it will be a pixmap of the file we have just set.
         self.lbl_CameraShow.setPixmap(image)
+
+    def updateImage2(self):
+       
+        # Close b - the greatly named variable - as i want to use it again! (Well close or declare it!)
+        b = None
+        # X-term - grab 10 buffered front camera images, and throw them into an image file.
+        # Everyone recommends 1.... but 10 gave more light! - so i used it :D
+        b = os.popen('gst-launch v4l2camsrc device=/dev/video0 num-buffers=10 ! dspjpegenc ! filesink location=/home/user/MyDocs/fcamtest.jpg')
+        b.close ()
+        # Declare and set the image file name
+        image_file = "/home/user/MyDocs/fcamtest.jpg"
+        image = QtGui.QPixmap(image_file)
+        # Declare image, and tell it, that it is a pixmap, and it will be a pixmap of the file we have just set.
+        self.lbl_CameraShow.setPixmap(image)
   
 # Funtion - update Firmware version label
     def updateMaemoV(self):
@@ -557,14 +603,29 @@ class Ui_MainWindow(object):
 
 # Funtion - update Accelerator information
     def updateAccel(self):
+        import dbus.glib
+
         # set f to = the accellerometer co-ordinates
         # the co-ords need to be pulled out and split for easy reading
         # Close down the co-ord file once used (Only displaying static info, not updating yet)
         f = open("/sys/class/i2c-adapter/i2c-3/3-001d/coord", 'r')
         coords = [int(w) for w in f.readline().split()]
         f.close()
-        self.lbl_Accel_Info.setText(str(coords))
 
+        b = None
+        b = os.popen('run-standalone.sh dbus-send --system --type=signal /com/nokia/mce/signal com.nokia.mce.signal.sig_device_orientation_ind').read()
+        coords = str(coords)
+        jaccel = str(coords) + str(b)
+        print jaccel
+        self.lbl_Accel_Info.setText(jaccel)
+
+        
+        #Bluetooth
+        #print "performing inquiry..."
+        #nearby_devices = bluetooth.discover_devices(lookup_names = True)
+        #print "found %d devices" % len(nearby_devices)
+        #for name, addr in nearby_devices:
+            #print "  %s - %s" % (addr, name)
 
 
 
@@ -625,12 +686,19 @@ class Ui_MainWindow(object):
         self.pushButton_cam.setEnabled(False)
         self.pushButton_cam.setText("....")
         Thread(target=self.updateImage()).start()
-        self.pushButton_cam.setText("Update")
+        self.pushButton_cam.setText("Front camera")
         self.pushButton_cam.setEnabled(True)
+
+    def updateTab3a(self):
+        self.pushButton_cam2.setEnabled(False)
+        self.pushButton_cam2.setText("....")
+        Thread(target=self.updateImage2()).start()
+        self.pushButton_cam2.setText("Back Camera")
+        self.pushButton_cam2.setEnabled(True)
         
     # This is the start of the QT Designer translation function - not using the translation function, but left it in, to show it is part of the class   
     def retranslateUi(self, MainWindow):
-        MainWindow.setWindowTitle(QtGui.QApplication.translate("MainWindow", "Health Check 0.5.0-9", None, QtGui.QApplication.UnicodeUTF8))
+        MainWindow.setWindowTitle(QtGui.QApplication.translate("MainWindow", "Health Check 0.5.1-1", None, QtGui.QApplication.UnicodeUTF8))
         self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab), QtGui.QApplication.translate("MainWindow", "System", None, QtGui.QApplication.UnicodeUTF8))
         self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_2), QtGui.QApplication.translate("MainWindow", "Comms", None, QtGui.QApplication.UnicodeUTF8))
         self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_3), QtGui.QApplication.translate("MainWindow", "Camera", None, QtGui.QApplication.UnicodeUTF8))
